"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tape_1 = __importDefault(require("tape"));
const _1 = __importDefault(require("./"));
const ownership_1 = require("./ownership");
const api = new _1.default('http://localhost:1317');
const address = "mesgtest19k9xsdy42f4a7f7777wj4rs5eh9622h2z7mzdh";
const mnemonic = "afford problem shove post clump space govern reward fringe input owner knock toddler orange castle course pepper fox youth field ritual wife weapon desert";
const serviceHash = "8K1X1rfEL1WCwpm2zBwsWH3bijyNuYWTN3LKoBP4Bkfy";
const runnerHash = "J58btTi41BJ6gjFyap9w1eRZnpTrf165vDQfpdiwPpXo";
const instanceHash = "9dq5UXSe1YBmB46c3Fs1YfQS49tyzew27qpYGGzFsQX8";
const processHash = "AAgUaBch3qycWsDGMFacbe7pcSHFhX968KDiKMfvw4ej";
// const eventHash = "6aUPZhmnFKiSsHXRaddbnqsKKi9KogbQNiKUcpivaohb"
// const executionHash = "ErrDsCUCRTucQeynBqxabyMTCkiBicRzuMKqaArhomyN"
const service = {
    sid: "js-function",
    name: "js-function",
    configuration: {},
    tasks: [{
            key: "execute",
            inputs: [
                { key: "code", type: "String" },
                { key: "inputs", type: "Any" }
            ],
            outputs: [
                { key: "result", type: "Any" }
            ]
        }],
    source: "QmV9uGGMPcaF22TjBJEcko6VxjJpK3wdtaypHEbh6j4Pz9"
};
const process = {
    name: 'test',
    nodes: [{
            key: 'trigger',
            Type: {
                type: "mesg.types.Process_Node_Event_",
                value: {
                    event: {
                        eventKey: 'xxx',
                        instanceHash
                    }
                }
            }
        }, {
            key: 'task',
            Type: {
                type: 'mesg.types.Process_Node_Task_',
                value: {
                    task: {
                        instanceHash,
                        taskKey: 'execute'
                    }
                }
            },
        }],
    edges: [{
            src: 'trigger',
            dst: 'task'
        }]
};
tape_1.default('service', (tt) => __awaiter(void 0, void 0, void 0, function* () {
    tt.test('service hash', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(1);
        const h = yield api.service.hash(service);
        t.equal(h, serviceHash);
    }));
    tt.test('service create', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(3);
        const account = yield api.account.get(address);
        const tx = yield api.createTransaction([
            api.service.createMsg(account.address, service)
        ], account, {
            fee: {
                amount: [{ denom: 'atto', amount: '66058' }],
                gas: '66058'
            }
        });
        const res = yield api.broadcast(yield tx.signWithMnemonic(mnemonic));
        t.assert(parseInt(res.height, 10) > 0);
        t.assert(res.txhash !== '');
        t.assert(!res.code);
    }));
    tt.test('service list', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(1);
        const services = yield api.service.list();
        t.equal(services.length, 1);
    }));
    tt.test('service get', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(1);
        const service = yield api.service.get(serviceHash);
        t.equal(service.hash, serviceHash);
    }));
    tt.test('service exists', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(2);
        const exists = yield api.service.exists(serviceHash);
        const notExists = yield api.service.exists("Dodtu7zTjLNmwbyauavch6gZZrzVaWUh6Aaaaaaaaaaa");
        t.equal(exists, true);
        t.equal(notExists, false);
    }));
}));
tape_1.default('ownership', (tt) => __awaiter(void 0, void 0, void 0, function* () {
    tt.test('ownership list', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(4);
        const ownerships = yield api.ownership.list();
        t.assert(ownerships.length === 1);
        t.assert(ownerships[0].owner === address);
        t.assert(ownerships[0].resourceHash === serviceHash);
        t.assert(ownerships[0].resource === ownership_1.Resource.Service);
    }));
}));
tape_1.default('runner', (tt) => __awaiter(void 0, void 0, void 0, function* () {
    tt.test('runner not exists', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(1);
        const res = yield api.runner.exists(runnerHash);
        t.false(res);
    }));
    tt.test('runner create', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(2);
        const account = yield api.account.get(address);
        const tx = yield api.createTransaction([
            api.runner.createMsg(account.address, serviceHash, serviceHash) // fake env hash
        ], account, {
            fee: {
                amount: [{ denom: 'atto', amount: '200000' }],
                gas: '200000'
            }
        });
        const res = yield api.broadcast(yield tx.signWithMnemonic(mnemonic));
        t.assert(parseInt(res.height, 10) > 0);
        t.assert(!res.code);
    }));
    tt.test('runner exists', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(1);
        const res = yield api.runner.exists(runnerHash);
        t.true(res);
    }));
    tt.test('runner list', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(3);
        const runners = yield api.runner.list();
        t.assert(runners.length === 1);
        t.assert(runners[0].hash === runnerHash);
        t.assert(runners[0].instanceHash === instanceHash);
    }));
    tt.test('runner get', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(2);
        const runner = yield api.runner.get(runnerHash);
        t.assert(runner.hash === runnerHash);
        t.assert(runner.instanceHash === instanceHash);
    }));
    tt.test('runner delete', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(2);
        const account = yield api.account.get(address);
        const tx = yield api.createTransaction([
            api.runner.deleteMsg(account.address, runnerHash)
        ], account, {
            fee: {
                amount: [{ denom: 'atto', amount: '200000' }],
                gas: '200000'
            }
        });
        const res = yield api.broadcast(yield tx.signWithMnemonic(mnemonic));
        t.assert(parseInt(res.height, 10) > 0);
        t.assert(!res.code);
    }));
    tt.test('runner create (to keep for the rest of the test)', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(2);
        const account = yield api.account.get(address);
        const tx = yield api.createTransaction([
            api.runner.createMsg(account.address, serviceHash, serviceHash) // fake env hash
        ], account, {
            fee: {
                amount: [{ denom: 'atto', amount: '200000' }],
                gas: '200000'
            }
        });
        const res = yield api.broadcast(yield tx.signWithMnemonic(mnemonic));
        t.assert(parseInt(res.height, 10) > 0);
        t.assert(!res.code);
    }));
}));
tape_1.default('instance', (tt) => __awaiter(void 0, void 0, void 0, function* () {
    tt.test('instance list', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(3);
        const instances = yield api.instance.list();
        t.assert(instances.length === 1);
        t.assert(instances[0].hash === instanceHash);
        t.assert(instances[0].serviceHash === serviceHash);
    }));
    tt.test('instance get', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(2);
        const instance = yield api.instance.get(instanceHash);
        t.assert(instance.hash === instanceHash);
        t.assert(instance.serviceHash === serviceHash);
    }));
}));
// test('execution', async (tt: Test) => {
//   tt.test('execution create', async (t: Test) => {
//     t.plan(1)
//     const execution = await api.execution.create({
//       eventHash: b58.decode(eventHash),
//       executorHash: b58.decode(runnerHash),
//       inputs: encode({
//         code: 'module.export = inputs => inputs * 2',
//         inputs: 21
//       }),
//       taskKey: 'execute'
//     })
//     t.assert(b58.encode(execution.hash) === executionHash)
//   })
//   tt.test('execution create', async (t: Test) => {
//     t.plan(1)
//     const account = await api.account.get(address)
//     const tx = await api.createTransaction([
//       api.execution.createMsg(
//         address,
//         runnerHash,
//         "execute",
//         { code: "module.export = inputs => inputs * 2", inputs: 21 },
//         null,
//         eventHash,
//         null,
//         null,
//         []
//       )
//     ], account, {
//       fee: {
//         amount: [{ denom: 'atto', amount: '200000' }],
//         gas: '200000'
//       }
//     })
//     const res = await api.broadcast(await tx.signWithMnemonic(mnemonic))
//     t.assert(parseInt(res.height, 10) > 0)
//   })
//   tt.test('execution update', async (t: Test) => {
//     t.plan(1)
//     await api.execution.update({
//       hash: b58.decode(executionHash),
//       outputs: encode({
//         result: 42
//       })
//     })
//     t.pass()
//   })
//   tt.test('execution list', async (t: Test) => {
//     t.plan(2)
//     const executions = await api.execution.list()
//     t.assert(executions.length === 1)
//     t.assert(executions[0].hash === executionHash)
//   });
//   tt.test('execution get', async (t: Test) => {
//     t.plan(5)
//     const execution = await api.execution.get(executionHash)
//     t.assert(execution.hash === executionHash)
//     t.assert(execution.executorHash === runnerHash)
//     t.assert(execution.instanceHash === instanceHash)
//     t.assert(execution.eventHash === eventHash)
//     t.assert(execution.taskKey === 'execute')
//   });
// })
tape_1.default('process', (tt) => __awaiter(void 0, void 0, void 0, function* () {
    tt.test('process hash', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(1);
        const h = yield api.process.hash(process);
        t.equal(h, processHash);
    }));
    tt.test('process create', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(3);
        const account = yield api.account.get(address);
        const tx = yield api.createTransaction([
            api.process.createMsg(account.address, process)
        ], account, {
            fee: {
                amount: [{ denom: 'atto', amount: '88801' }],
                gas: '88801'
            }
        });
        const res = yield api.broadcast(yield tx.signWithMnemonic(mnemonic));
        t.assert(parseInt(res.height, 10) > 0);
        t.assert(res.txhash !== '');
        t.assert(!res.code);
    }));
    tt.test('process list', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(1);
        const processes = yield api.process.list();
        t.equal(processes.length, 1);
    }));
    tt.test('process get', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(1);
        const process = yield api.process.get(processHash);
        t.equal(process.hash, processHash);
    }));
    tt.test('process exists', (t) => __awaiter(void 0, void 0, void 0, function* () {
        t.plan(2);
        const exists = yield api.process.exists(processHash);
        const notExists = yield api.process.exists("Dodtu7zTjLNmwbyauavch6gZZrzVaWUh6Aaaaaaaaaaa");
        t.equal(exists, true);
        t.equal(notExists, false);
    }));
}));
